<div class="modal-header">
    <h4>{{service.name}}</h4>
</div>
<div class="modal-body">
    <pre>{{status}}</pre>
</div>
<div class="modal-footer">
    <a ng:click="close()" class="btn btn-default btn-flat" translate>Close</a>
</div>