{"": "", "Close": "Schlie\u00dfen", "Disabled": "Deaktiviert", "Filter services": "Services filtern", "Manager": "Manager", "Service": "Dienst", "Static": "Statisch", "Services": "Dienste", "Manage system services": "Verwalten von Systemdiensten", "Service operation failed": "Service Operation fehlgeschlagen", "Stop service": "Dienst beenden", "Start service": "Dienst starten", "Restart service": "Dienst neu starten", "Kill service": "Dienst stoppen", "Enable service": "Dienst aktivieren", "Disable service": "Dienst deaktivieren", "Done": "Erledigt"}