{"": "", "Close": "", "Disabled": "", "Filter services": "Filtrul serviciilor", "Manager": "Manager", "Service": "Serviciu", "Static": "", "Services": "Servicii", "Manage system services": "Gestionarea serviciilor de sistem", "Service operation failed": "Opera\u021bia serviciului a e\u0219uat", "Stop service": "", "Start service": "", "Restart service": "", "Kill service": "", "Enable service": "", "Disable service": "", "Done": "Efectuat"}