{"": "", "Close": "", "Disabled": "", "Filter services": "\u7b5b\u9009\u5668\u670d\u52a1", "Manager": "\u7ba1\u7406\u5668", "Service": "\u670d\u52a1", "Static": "", "Services": "\u670d\u52a1", "Manage system services": "\u7ba1\u7406\u7cfb\u7edf\u670d\u52a1", "Service operation failed": "\u670d\u52a1\u64cd\u4f5c\u5931\u8d25", "Stop service": "", "Start service": "", "Restart service": "", "Kill service": "", "Enable service": "", "Disable service": "", "Done": "\u5df2\u5b8c\u6210"}