{"": "", "Close": "Zamknij", "Disabled": "Wy\u0142\u0105czone", "Filter services": "Filtr us\u0142ug", "Manager": "Mened\u017cer", "Service": "Us\u0142uga", "Static": "Statyczne", "Services": "Us\u0142ugi", "Manage system services": "Zarz\u0105dzaj us\u0142ugami systemowymi", "Service operation failed": "Operacja us\u0142ugi nie powiod\u0142a si\u0119", "Stop service": "Zatrzymaj us\u0142ug\u0119", "Start service": "Uruchom us\u0142ug\u0119", "Restart service": "Uruchom ponownie us\u0142ug\u0119", "Kill service": "Zabij us\u0142ug\u0119", "Enable service": "W\u0142\u0105cz us\u0142ug\u0119", "Disable service": "Wy\u0142\u0105cz us\u0142ug\u0119", "Done": "Gotowe"}