{"": "", "Close": "Fermer", "Disabled": "D\u00e9sactiv\u00e9", "Filter services": "Filtrer les services", "Manager": "Gestionnaire", "Service": "Service", "Static": "Statique", "Services": "Services", "Manage system services": "G\u00e9rer les services syst\u00e8me", "Service operation failed": "L'op\u00e9ration de service a \u00e9chou\u00e9", "Stop service": "Arr\u00eater le service", "Start service": "D\u00e9marrer le service", "Restart service": "Red\u00e9marrer le service", "Kill service": "Stopper le service", "Enable service": "Activer le service", "Disable service": "D\u00e9sactiver le service", "Done": "Fait"}