{"": "", "Close": "Chiudi", "Disabled": "Disabilitato", "Filter services": "Filtro servizi", "Manager": "Gestione", "Service": "Servizio", "Static": "Statico", "Services": "Servizi", "Manage system services": "Gestire dei servizi di sistema", "Service operation failed": "Operazione del servizio fallita", "Stop service": "Interrompi servizio", "Start service": "Avvia servizio", "Restart service": "Riavvia servizio", "Kill service": "Termina servizio", "Enable service": "Abilita servizio", "Disable service": "Disabilita servizio", "Done": "Fatto"}