{"": "", "Close": "Cerrar", "Disabled": "Deshabilitado", "Filter services": "Filtrar servicios", "Manager": "Administrador", "Service": "Servicio", "Static": "Est\u00e1tico", "Services": "Servicios", "Manage system services": "Administrar los servicios del sistema", "Service operation failed": "Fall\u00f3 la operaci\u00f3n del servicio", "Stop service": "Detener servicio", "Start service": "Empezar servicio", "Restart service": "Reiniciar servicio", "Kill service": "Matar servicio", "Enable service": "Habilitar servicio", "Disable service": "Deshabilitar servicio", "Done": "Hecho"}