{"": "", "Close": "St\u00e4ng", "Disabled": "Inaktiverad", "Filter services": "Filtrera tj\u00e4nster", "Manager": "Hanterare", "Service": "Tj\u00e4nst", "Static": "Statisk", "Services": "Tj\u00e4nster", "Manage system services": "Hantera systemtj\u00e4nster", "Service operation failed": "\u00c5tg\u00e4rden misslyckades", "Stop service": "Stoppa tj\u00e4nst", "Start service": "Starta tj\u00e4nst", "Restart service": "Starta om tj\u00e4nst", "Kill service": "D\u00f6da tj\u00e4nst", "Enable service": "Aktivera tj\u00e4nst", "Disable service": "Inaktivera tj\u00e4nst", "Done": "Klar"}