{"": "", "Close": "", "Disabled": "", "Filter services": "Filtre hizmetleri", "Manager": "Y\u00f6netici", "Service": "Hizmet", "Static": "", "Services": "Hizmetler", "Manage system services": "Sistem hizmetlerini y\u00f6net", "Service operation failed": "Servis i\u015flemi ba\u015far\u0131s\u0131z oldu", "Stop service": "", "Start service": "", "Restart service": "", "Kill service": "", "Enable service": "", "Disable service": "", "Done": "Tamam"}