{"": "", "Close": "", "Disabled": "", "Filter services": "Filter services", "Manager": "Manager", "Service": "Service", "Static": "", "Services": "Services", "Manage system services": "Beheren van systeemservices", "Service operation failed": "", "Stop service": "", "Start service": "", "Restart service": "", "Kill service": "", "Enable service": "", "Disable service": "", "Done": ""}