{"": "", "Close": "", "Disabled": "", "Filter services": "Servi\u00e7os de filtro", "Manager": "Gerenciador", "Service": "Servi\u00e7o", "Static": "", "Services": "Servi\u00e7os", "Manage system services": "Gerenciar servi\u00e7os do sistema", "Service operation failed": "Falha na opera\u00e7\u00e3o do servi\u00e7o", "Stop service": "", "Start service": "", "Restart service": "", "Kill service": "", "Enable service": "", "Disable service": "", "Done": "Conclu\u00eddo"}